Release notes — Rucio 1.2 documentation

# Release notes

Rucio release notes are available here or directly on github.

## Release notes

- 1.15.4
- 1.15.3
- 1.15.2
- 1.15.1 (webui only)
- 1.15.0 “Daredonkey”
- 1.14.9
- 1.14.8
- 1.14.7
- 1.14.6
- 1.14.5
- 1.14.4
- 1.14.3
- 1.14.2
- 1.14.11
- 1.14.1
- 1.14.0 “Professor D”
- 1.13.3

## Previous feature releases

- 1.13.0 “Donkerine”
- 1.12.0 “Captain Donkey”
- 1.11.0 “Batdonkey”
- 1.10.0 “Irondonkey”
- 1.9.0 “Superdonkey”
- 1.8.0 “Spiderdonkey”
- 1.7.0 “Donkey One”
- 1.6.0 “The Donkey awakens”
- 1.5.0 “Return of the Donkey”
- 1.4.0 “The Donkey strikes back”
- 1.3.0
- 1.2.0
- 1.1.0
- 1.0.0